@@ -29,7 +29,7 @@
   POSSIBILITY OF SUCH DAMAGE. 
 */
 
-/* $Id: iom168p.h,v 1.3.2.6 2008/03/19 21:25:13 arcanum Exp $ */
+/* $Id: iom168p.h,v 1.3.2.12 2009/02/11 18:05:27 arcanum Exp $ */
 
 /* avr/iom168p.h - definitions for ATmega168P. */
 
@@ -244,14 +244,14 @@
 #define TCNT0_7 7
 
 #define OCR0A _SFR_IO8(0x27)
-#define OCROA_0 0
-#define OCROA_1 1
-#define OCROA_2 2
-#define OCROA_3 3
-#define OCROA_4 4
-#define OCROA_5 5
-#define OCROA_6 6
-#define OCROA_7 7
+#define OCR0A_0 0
+#define OCR0A_1 1
+#define OCR0A_2 2
+#define OCR0A_3 3
+#define OCR0A_4 4
+#define OCR0A_5 5
+#define OCR0A_6 6
+#define OCR0A_7 7
 
 #define OCR0B _SFR_IO8(0x28)
 #define OCR0B_0 0
@@ -438,7 +438,10 @@
 #define OCIE2A 1
 #define OCIE2B 2
 
-#define ADC _SFR_MEM16(0x78)
+#ifndef __ASSEMBLER__
+#define ADC     _SFR_MEM16(0x78)
+#endif
+#define ADCW    _SFR_MEM16(0x78)
 
 #define ADCL _SFR_MEM8(0x78)
 #define ADCL0 0
@@ -816,8 +819,9 @@
 #define SPM_PAGESIZE 128
 #define RAMEND       0x4FF     /* Last On-Chip SRAM Location */
 #define XRAMSIZE     0
-#define XRAMEND      (RAMEND + XRAMSIZE)
+#define XRAMEND      RAMEND
 #define E2END        0x1FF
+#define E2PAGESIZE   4
 #define FLASHEND     0x3FFF
 
 
@@ -826,31 +830,31 @@
 #define FUSE_MEMORY_SIZE 3
 
 /* Low Fuse Byte */
-#define FUSE_CKSEL0 ~_BV(0)  /* Select Clock Source */
-#define FUSE_CKSEL1 ~_BV(1)  /* Select Clock Source */
-#define FUSE_CKSEL2 ~_BV(2)  /* Select Clock Source */
-#define FUSE_CKSEL3 ~_BV(3)  /* Select Clock Source */
-#define FUSE_SUT0   ~_BV(4)  /* Select start-up time */
-#define FUSE_SUT1   ~_BV(5)  /* Select start-up time */
-#define FUSE_CKOUT  ~_BV(6)  /* Clock output */
-#define FUSE_CKDIV8 ~_BV(7) /* Divide clock by 8 */
+#define FUSE_CKSEL0 (unsigned char)~_BV(0)  /* Select Clock Source */
+#define FUSE_CKSEL1 (unsigned char)~_BV(1)  /* Select Clock Source */
+#define FUSE_CKSEL2 (unsigned char)~_BV(2)  /* Select Clock Source */
+#define FUSE_CKSEL3 (unsigned char)~_BV(3)  /* Select Clock Source */
+#define FUSE_SUT0   (unsigned char)~_BV(4)  /* Select start-up time */
+#define FUSE_SUT1   (unsigned char)~_BV(5)  /* Select start-up time */
+#define FUSE_CKOUT  (unsigned char)~_BV(6)  /* Clock output */
+#define FUSE_CKDIV8 (unsigned char)~_BV(7) /* Divide clock by 8 */
 #define LFUSE_DEFAULT (FUSE_CKSEL0 & FUSE_CKSEL2 & FUSE_CKSEL3 & FUSE_SUT0 & FUSE_CKDIV8)
 
 /* High Fuse Byte */
-#define FUSE_BODLEVEL0 ~_BV(0)  /* Brown-out Detector trigger level */
-#define FUSE_BODLEVEL1 ~_BV(1)  /* Brown-out Detector trigger level */
-#define FUSE_BODLEVEL2 ~_BV(2)  /* Brown-out Detector trigger level */
-#define FUSE_EESAVE    ~_BV(3)  /* EEPROM memory is preserved through chip erase */
-#define FUSE_WDTON     ~_BV(4)  /* Watchdog Timer Always On */
-#define FUSE_SPIEN     ~_BV(5)  /* Enable Serial programming and Data Downloading */
-#define FUSE_DWEN      ~_BV(6)  /* debugWIRE Enable */
-#define FUSE_RSTDISBL  ~_BV(7)  /* External reset disable */
+#define FUSE_BODLEVEL0 (unsigned char)~_BV(0)  /* Brown-out Detector trigger level */
+#define FUSE_BODLEVEL1 (unsigned char)~_BV(1)  /* Brown-out Detector trigger level */
+#define FUSE_BODLEVEL2 (unsigned char)~_BV(2)  /* Brown-out Detector trigger level */
+#define FUSE_EESAVE    (unsigned char)~_BV(3)  /* EEPROM memory is preserved through chip erase */
+#define FUSE_WDTON     (unsigned char)~_BV(4)  /* Watchdog Timer Always On */
+#define FUSE_SPIEN     (unsigned char)~_BV(5)  /* Enable Serial programming and Data Downloading */
+#define FUSE_DWEN      (unsigned char)~_BV(6)  /* debugWIRE Enable */
+#define FUSE_RSTDISBL  (unsigned char)~_BV(7)  /* External reset disable */
 #define HFUSE_DEFAULT (FUSE_SPIEN)
 
 /* Extended Fuse Byte */
-#define FUSE_BOOTRST ~_BV(0)
-#define FUSE_BOOTSZ0 ~_BV(1)
-#define FUSE_BOOTSZ1 ~_BV(2)
+#define FUSE_BOOTRST (unsigned char)~_BV(0)
+#define FUSE_BOOTSZ0 (unsigned char)~_BV(1)
+#define FUSE_BOOTSZ1 (unsigned char)~_BV(2)
 #define EFUSE_DEFAULT (FUSE_BOOTSZ0 & FUSE_BOOTSZ1)
 
 
@@ -861,4 +865,10 @@
 #define __BOOT_LOCK_BITS_1_EXIST 
 
 
+/* Signature */
+#define SIGNATURE_0 0x1E
+#define SIGNATURE_1 0x94
+#define SIGNATURE_2 0x0B
+
+
 #endif  /* _AVR_IOM168P_H_ */
