@@ -30,7 +30,7 @@
 
 /* avr/iom324.h - definitions for ATmega324 */
 
-/* $Id: iom324.h,v 1.3.2.2 2008/01/06 20:10:44 arcanum Exp $ */
+/* $Id: iom324.h,v 1.3.2.5 2009/02/11 18:05:27 arcanum Exp $ */
 
 #ifndef _AVR_IOM324_H_
 #define _AVR_IOM324_H_ 1
@@ -40,8 +40,9 @@
 /* Constants */
 #define SPM_PAGESIZE    128
 #define RAMEND          0x08FF
-#define XRAMEND         0x08FF
+#define XRAMEND         RAMEND
 #define E2END           0x3FF
+#define E2PAGESIZE      4
 #define FLASHEND        0x7FFF
 
 
@@ -50,31 +51,31 @@
 #define FUSE_MEMORY_SIZE 3
 
 /* Low Fuse Byte */
-#define FUSE_CKSEL0      ~_BV(0)
-#define FUSE_CKSEL1      ~_BV(1)
-#define FUSE_CKSEL2      ~_BV(2)
-#define FUSE_CKSEL3      ~_BV(3)
-#define FUSE_SUT0        ~_BV(4)
-#define FUSE_SUT1        ~_BV(5)
-#define FUSE_CKOUT       ~_BV(6)
-#define FUSE_CKDIV8      ~_BV(7)
+#define FUSE_CKSEL0      (unsigned char)~_BV(0)
+#define FUSE_CKSEL1      (unsigned char)~_BV(1)
+#define FUSE_CKSEL2      (unsigned char)~_BV(2)
+#define FUSE_CKSEL3      (unsigned char)~_BV(3)
+#define FUSE_SUT0        (unsigned char)~_BV(4)
+#define FUSE_SUT1        (unsigned char)~_BV(5)
+#define FUSE_CKOUT       (unsigned char)~_BV(6)
+#define FUSE_CKDIV8      (unsigned char)~_BV(7)
 #define LFUSE_DEFAULT (FUSE_CKSEL0 & FUSE_CKSEL2 & FUSE_CKSEL3 & FUSE_SUT0 & FUSE_SUT1 & FUSE_CKDIV8)
 
 /* High Fuse Byte */
-#define FUSE_BOOTRST     ~_BV(0)
-#define FUSE_BOOTSZ0     ~_BV(1)
-#define FUSE_BOOTSZ1     ~_BV(2)
-#define FUSE_EESAVE      ~_BV(3)
-#define FUSE_WDTON       ~_BV(4)
-#define FUSE_SPIEN       ~_BV(5)
-#define FUSE_JTAGEN      ~_BV(6)
-#define FUSE_OCDEN       ~_BV(7)
+#define FUSE_BOOTRST     (unsigned char)~_BV(0)
+#define FUSE_BOOTSZ0     (unsigned char)~_BV(1)
+#define FUSE_BOOTSZ1     (unsigned char)~_BV(2)
+#define FUSE_EESAVE      (unsigned char)~_BV(3)
+#define FUSE_WDTON       (unsigned char)~_BV(4)
+#define FUSE_SPIEN       (unsigned char)~_BV(5)
+#define FUSE_JTAGEN      (unsigned char)~_BV(6)
+#define FUSE_OCDEN       (unsigned char)~_BV(7)
 #define HFUSE_DEFAULT (FUSE_BOOTSZ0 & FUSE_BOOTSZ1 & FUSE_SPIEN & FUSE_JTAGEN)
 
 /* Extended Fuse Byte */
-#define FUSE_BODLEVEL0   ~_BV(0)
-#define FUSE_BODLEVEL1   ~_BV(1)
-#define FUSE_BODLEVEL2   ~_BV(2)
+#define FUSE_BODLEVEL0   (unsigned char)~_BV(0)
+#define FUSE_BODLEVEL1   (unsigned char)~_BV(1)
+#define FUSE_BODLEVEL2   (unsigned char)~_BV(2)
 #define EFUSE_DEFAULT (0xFF)
 
 
