@@ -29,7 +29,7 @@
   POSSIBILITY OF SUCH DAMAGE. 
 */
 
-/* $Id: iom32u4.h,v 1.1.2.4 2008/04/01 17:39:46 arcanum Exp $ */
+/* $Id: iom32u4.h,v 1.1.2.11 2009/02/11 18:05:28 arcanum Exp $ */
 
 /* avr/iom32u4.h - definitions for ATmega32U4. */
 
@@ -293,14 +293,14 @@
 #define TCNT0_7 7
 
 #define OCR0A _SFR_IO8(0x27)
-#define OCROA_0 0
-#define OCROA_1 1
-#define OCROA_2 2
-#define OCROA_3 3
-#define OCROA_4 4
-#define OCROA_5 5
-#define OCROA_6 6
-#define OCROA_7 7
+#define OCR0A_0 0
+#define OCR0A_1 1
+#define OCR0A_2 2
+#define OCR0A_3 3
+#define OCR0A_4 4
+#define OCR0A_5 5
+#define OCR0A_6 6
+#define OCR0A_7 7
 
 #define OCR0B _SFR_IO8(0x28)
 #define OCR0B_0 0
@@ -442,7 +442,7 @@
 #define CLKPS1 1
 #define CLKPS2 2
 #define CLKPS3 3
-#define CLKPCE 4
+#define CLKPCE 7
 
 #define PRR0 _SFR_MEM8(0x64)
 #define PRADC 0
@@ -578,8 +578,8 @@
 #define ADTS2 2
 #define ADTS3 4
 #define MUX5 5
-#define ADHSM 6
-#define ACME 7
+#define ACME 6
+#define ADHSM 7
 
 #define ADMUX _SFR_MEM8(0x7C)
 #define MUX0 0
@@ -591,7 +591,7 @@
 #define REFS0 6
 #define REFS1 7
 
-#define DDIR2 _SFR_MEM8(0x7D)
+#define DIDR2 _SFR_MEM8(0x7D)
 #define ADC8D 0
 #define ADC9D 1
 #define ADC10D 2
@@ -633,7 +633,7 @@
 #define ICNC1 7
 
 #define TCCR1C _SFR_MEM8(0x82)
-#define FOC1C 1 
+#define FOC1C 5 
 #define FOC1B 6 
 #define FOC1A 7 
 
@@ -1146,20 +1146,8 @@
 #define UBRR1 _SFR_MEM16(0xCC)
 
 #define UBRR1L _SFR_MEM8(0xCC)
-#define UBRR0 0
-#define UBRR1 1
-#define UBRR2 2
-#define UBRR3 3
-#define UBRR4 4
-#define UBRR5 5
-#define UBRR6 6
-#define UBRR7 7
 
 #define UBRR1H _SFR_MEM8(0xCD)
-#define UBRR8 0
-#define UBRR9 1
-#define UBRR10 2
-#define UBRR11 3
 
 #define UDR1 _SFR_MEM8(0xCE)
 #define UDR1_0 0
@@ -1452,13 +1440,13 @@
 
 
 /* Constants */
-#define SPM_PAGESIZE (64)
+#define SPM_PAGESIZE (128)
 #define RAMSTART     (0x100)
 #define RAMSIZE      (0xA00)
 #define RAMEND       (RAMSTART + RAMSIZE - 1)  /* Last On-Chip SRAM Location */
 #define XRAMSTART    (0x2200)
 #define XRAMSIZE     (0x10000)
-#define XRAMEND      (XRAMSTART + XRAMSIZE - 1)
+#define XRAMEND      (XRAMSIZE - 1)
 #define E2END        (0x3FF)
 #define E2PAGESIZE   (4) 
 #define FLASHEND     (0x7FFF)
@@ -1469,32 +1457,32 @@
 #define FUSE_MEMORY_SIZE 3
 
 /* Low Fuse Byte */
-#define FUSE_CKSEL0 ~_BV(0)  /* Select Clock Source */
-#define FUSE_CKSEL1 ~_BV(1)  /* Select Clock Source */
-#define FUSE_CKSEL2 ~_BV(2)  /* Select Clock Source */
-#define FUSE_CKSEL3 ~_BV(3)  /* Select Clock Source */
-#define FUSE_SUT0   ~_BV(4)  /* Select start-up time */
-#define FUSE_SUT1   ~_BV(5)  /* Select start-up time */
-#define FUSE_CKOUT  ~_BV(6)  /* Oscillator options */
-#define FUSE_CKDIV8 ~_BV(7)  /* Divide clock by 8 */
+#define FUSE_CKSEL0 (unsigned char)~_BV(0)  /* Select Clock Source */
+#define FUSE_CKSEL1 (unsigned char)~_BV(1)  /* Select Clock Source */
+#define FUSE_CKSEL2 (unsigned char)~_BV(2)  /* Select Clock Source */
+#define FUSE_CKSEL3 (unsigned char)~_BV(3)  /* Select Clock Source */
+#define FUSE_SUT0   (unsigned char)~_BV(4)  /* Select start-up time */
+#define FUSE_SUT1   (unsigned char)~_BV(5)  /* Select start-up time */
+#define FUSE_CKOUT  (unsigned char)~_BV(6)  /* Oscillator options */
+#define FUSE_CKDIV8 (unsigned char)~_BV(7)  /* Divide clock by 8 */
 #define LFUSE_DEFAULT (FUSE_CKSEL1 & FUSE_CKSEL2 & FUSE_CKSEL3 & FUSE_SUT1 & FUSE_CKDIV8)
 
 /* High Fuse Byte */
-#define FUSE_BOOTRST ~_BV(0)  /* Select Reset Vector */
-#define FUSE_BOOTSZ0 ~_BV(1)  /* Select Boot Size */
-#define FUSE_BOOTSZ1 ~_BV(2)  /* Select Boot Size */
-#define FUSE_EESAVE  ~_BV(3)  /* EEPROM memory is preserved through chip erase */
-#define FUSE_WDTON   ~_BV(4)  /* Watchdog timer always on */
-#define FUSE_SPIEN   ~_BV(5)  /* Enable Serial programming and Data Downloading */
-#define FUSE_JTAGEN  ~_BV(6)  /* Enable JTAG */
-#define FUSE_OCDEN   ~_BV(7)  /* Enable OCD */
+#define FUSE_BOOTRST (unsigned char)~_BV(0)  /* Select Reset Vector */
+#define FUSE_BOOTSZ0 (unsigned char)~_BV(1)  /* Select Boot Size */
+#define FUSE_BOOTSZ1 (unsigned char)~_BV(2)  /* Select Boot Size */
+#define FUSE_EESAVE  (unsigned char)~_BV(3)  /* EEPROM memory is preserved through chip erase */
+#define FUSE_WDTON   (unsigned char)~_BV(4)  /* Watchdog timer always on */
+#define FUSE_SPIEN   (unsigned char)~_BV(5)  /* Enable Serial programming and Data Downloading */
+#define FUSE_JTAGEN  (unsigned char)~_BV(6)  /* Enable JTAG */
+#define FUSE_OCDEN   (unsigned char)~_BV(7)  /* Enable OCD */
 #define HFUSE_DEFAULT (FUSE_BOOTSZ0 & FUSE_SPIEN)
 
 /* Extended Fuse Byte */
-#define FUSE_BODLEVEL0 ~_BV(0)  /* Brown-out Detector trigger level */
-#define FUSE_BODLEVEL1 ~_BV(1)  /* Brown-out Detector trigger level */
-#define FUSE_BODLEVEL2 ~_BV(2)  /* Brown-out Detector trigger level */
-#define FUSE_HWBE      ~_BV(3)  /* Hardware Boot Enable */
+#define FUSE_BODLEVEL0 (unsigned char)~_BV(0)  /* Brown-out Detector trigger level */
+#define FUSE_BODLEVEL1 (unsigned char)~_BV(1)  /* Brown-out Detector trigger level */
+#define FUSE_BODLEVEL2 (unsigned char)~_BV(2)  /* Brown-out Detector trigger level */
+#define FUSE_HWBE      (unsigned char)~_BV(3)  /* Hardware Boot Enable */
 #define EFUSE_DEFAULT (0xFF)
 
 
